package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.dto.OnlineDto;
import com.caimei365.user.model.po.CmDistribution;
import com.caimei365.user.model.po.CmUser;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.BaseService;
import com.caimei365.user.service.CmDistributionService;
import com.caimei365.user.service.SellerService;
import com.caimei365.user.utils.BeanUtil;
import com.caimei365.user.utils.RequestUtil;
import com.caimei365.user.utils.ValidateUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
@Api(tags = "分销人员API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/distribution")
public class DistributionApi {

    private final CmDistributionService cmDistributionService;
    private final BaseService baseService;


    /**
     * 团队成员列表
     */
    @GetMapping("/getDistributionList")
    public ResponseJson<List<CmDistributionVO>> getDistributionList(CmDistribution cmDistribution) {
        if (null == cmDistribution.parentId()) {
            return ResponseJson.error("参数异常！", null);
        }
        List<CmDistribution> cmDistributionList = cmDistributionService.getCmDistributionList(new CmDistribution()
                .parentId(cmDistribution.parentId())
        );
        return ResponseJson.success(BeanUtil.setValues(cmDistributionList,CmDistributionVO.class));
    }


    /**
     * 协销个人中心
     */
    @GetMapping("/home")
    public ResponseJson<CmDistributionVO> getHome(CmDistribution cmDistribution) {
        if (null == cmDistribution.userId()&&null == cmDistribution.id()) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        CmDistributionVO cmDistributionVO = BeanUtil.setValue(cmDistributionService.getByCmDistribution(new CmDistribution()
                .id(cmDistribution.id())
                .userId(cmDistribution.userId())
        ), CmDistributionVO.class);
        return ResponseJson.success(cmDistributionVO);
    }

    /**
     * 更新协销信息
     */
    @PostMapping("/setHome")
    public ResponseJson setHome(CmDistribution cmDistribution) {
        if (null == cmDistribution.userId()) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        cmDistributionService.updateCmDistribution(new CmDistribution()
                .userId(cmDistribution.userId())
                .image(cmDistribution.image())
                .qrCode(cmDistribution.qrCode())
        );
        return ResponseJson.success();
    }

    /**
     * 更新协销信息
     */
    @PostMapping("/setPassword")
    public ResponseJson setPassword(CmDistribution cmDistribution, String oldPassword,  String code) {
        if (!oldPassword.equals(cmDistribution.password())) {
            return ResponseJson.error("两次输入的密码不一致！", null);
        }
        return cmDistributionService.setPassword(new CmDistribution()
                        .userId(cmDistribution.userId())
                        .mobile(cmDistribution.mobile())
                        .password(cmDistribution.password())
                , code);
    }

    /**
     * 更新协销信息
     */
    @PostMapping("/updateStatus")
    public ResponseJson updateStatus(CmDistribution cmDistribution) {
        if (null == cmDistribution.userId()) {
            return ResponseJson.error("参数异常：用户Id不能为空！！", null);
        }
        if (90 != cmDistribution.status()) {
            cmDistribution.status(91);
        }
        cmDistributionService.updateCmDistribution(new CmDistribution()
                .userId(cmDistribution.userId())
                .status(cmDistribution.status())
        );
        return ResponseJson.success();
    }

    /**
     * 新增协销信息
     */
    @PostMapping("/save")
    public ResponseJson save(CmDistribution cmDistribution) {
        if (null == cmDistribution.parentId() || cmDistribution.parentId() == 0) {
            return ResponseJson.error("管理员ID不能为空！", null);
        }
        if (null == cmDistribution.name() || null == cmDistribution.mobile() || null == cmDistribution.status()) {
            return ResponseJson.error("参数异常！", null);
        }
        // 验证手机号
        String result = ValidateUtil.validateMobile(cmDistribution.mobile());
        if (result != null) {
            return ResponseJson.error(result);
        }
        if (90 != cmDistribution.status()) {
            cmDistribution.status(91);
        }
        CmDistribution cmDistributionById = cmDistribution.id()==null?null:cmDistributionService.getCmDistributionById(cmDistribution.id());
        CmUser cmUser = baseService.findUserByMobile(cmDistribution.mobile(),cmDistributionById==null?null:cmDistributionById.userId(),null);
        if (cmUser!=null) {
            return ResponseJson.error("手机号码已经被使用！", null);
        }
        cmDistributionService.addCmDistribution(cmDistribution);
        return ResponseJson.success();
    }

}
