package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.RoosInformationDto;
import com.caimei365.user.model.vo.CmShopPopUpVo;
import com.caimei365.user.model.vo.cmShopAdvertisingImage;
import com.caimei365.user.service.RoosInformationService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/12/9
 */
@Slf4j
@RestController
@RequestMapping( "/user/information")
public class RoosInformationApi {

    @Autowired private RoosInformationService roosInformationService;

    /**
     * 查看用户是否有过弹框，游客当天是否有过弹框
     * @return
     */
    @GetMapping("/isClick")
    public ResponseJson<Boolean> boolIsClick(Integer shopId, Integer productId, Integer infoId, String keyword) {

        // 获取访问ip
        String ip = roosInformationService.obtainIp();
        // 查看用户是否有过弹框，游客当天是否有过弹框
        Boolean isClick = roosInformationService.boolIsClick(ip, shopId, productId, infoId, keyword);
        return ResponseJson.success(isClick);
    }

    /**
     * 供应商弹框信息
     * @param shopId
     * @param productId
     * @param infoId
     * @param keyword
     * @return
     */
    @GetMapping("/getPopUpInfo")
    public ResponseJson<CmShopPopUpVo> getPopUpInfo(Integer shopId, Integer productId, Integer infoId, String keyword) {
        return roosInformationService.getPopUpInfo(shopId, productId, infoId, keyword);
    }

    /**
     * 插入填写咨询人基本信息
     * @param roosInformationDto
     * @return
     */
    @PostMapping("/insertRoos")
    public ResponseJson<String> insertRoosInformation(RoosInformationDto roosInformationDto) {
        if (null == roosInformationDto.getShopProductId()) {
            return ResponseJson.error(-1, "供应商商品Id不能为空", null);
        }
        // 获取访问ip
        String ip = roosInformationService.obtainIp();
        roosInformationDto.setIp(ip);
        return roosInformationService.insRoosInformation(roosInformationDto);
    }

    /**
     * 查看访问者是否浏览过供应商相关页面 供应商广告图
     * @return
     */
    @GetMapping("/getShopAdvert")
    public ResponseJson<List<cmShopAdvertisingImage>> selVisitRoos(Integer userId) {
        // 获取访问ip
        String ip = roosInformationService.obtainIp();
        return roosInformationService.selectVisitRoos(userId,ip);
    }
}
