package com.caimei365.user.mapper;

import com.caimei365.user.model.po.CmRelatedImage;
import com.caimei365.user.model.po.CmUser;
import com.caimei365.user.model.po.WxUnion;
import com.caimei365.user.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/10
 */
@Mapper
public interface BaseMapper {
    /**
     * 根据邮箱获取用户id
     *
     * @param email 邮箱
     * @return userId
     */
    Integer getUserIdByEmail(@Param("email") String email);

    /**
     * 根据用户Id查询用户是否存在
     * @param userId   用户Id
     * @return
     */
    Integer getUserIdByUserId(Integer userId);
    /**
     * 根据手机号获取用户Id
     *
     * @param mobile 手机号
     * @return 用户Id
     */
    Integer getUserIdByMobile(@Param("mobile") String mobile);
    /**
     * 根据手机号获取用户Id -- 组织
     *
     * @param mobile 手机号
     * @return 用户Id
     */
    Integer getUserIdOrganizeByMobile(@Param("mobile") String mobile);

    /**
     * 获取组织用户userId
     * @param organizeId
     * @param mobile
     * @return
     */
    Integer getUserIdByOrganize(@Param("organizeId") Integer organizeId, @Param("mobile") String mobile);

    /**
     * 获取协销信息
     * @param mobile
     * @return
     */
    UserLoginVo getServiceProvider(@Param("mobile") String mobile);
    /**
     * 获取组织机构审核状态
     * @param organizeId
     * @param mobile
     * @return
     */
    UserLoginVo getUserIdByOrganizeStatus(@Param("organizeId") Integer organizeId, @Param("mobile") String mobile);
    /**
     * 根据运营人员手机号获用户Id
     *
     * @param mobile 手机号
     * @return 用户Id
     */
    Integer getOperationUserIdByMobile(String mobile);

    /**
     * 根据用户Id获取机构状态
     * @param userId
     * @return
     */
    Integer getClubStatusByUserId(Integer userId);
    /**
     * 根据用户Id获取供应商状态
     * @param userId
     * @return
     */
    Integer getShopStatusByUserId(Integer userId);
    /**
     * 根据手机号获取运营人员Id
     *
     * @param mobile 手机号
     * @return userId
     */
    Integer getOperationIdByMobile(@Param("mobile") String mobile);

    /**
     * 根据手机号、组织Id获取运营人员Id
     * @param mobile
     * @param organizeId
     * @return
     */
    Integer getOrganizeOperationIdByMobile(@Param("mobile") String mobile, @Param("organizeId") Integer organizeId);

    /**
     * 省
     *
     * @param provinceId
     * @return
     */
    ProvinceVo getProvince(Integer provinceId);

    /**
     * 市
     *
     * @param cityId
     * @return
     */
    CityVo getCity(Integer cityId);

    /**
     * 区
     *
     * @param townId
     * @return
     */
    TownVo getTown(Integer townId);

    /**
     * 根据用户Id获取用户信息
     * @param userId    用户Id
     * @return
     */
    UserVo getUserByUserId(Integer userId);

    /**
     * 根据用户Id获取用户名
     * @param userId    用户Id
     * @return
     */
    String getUserNameByUserId(Integer userId);
    /**
     * 获取采美售后电话
     * @return
     */
    String getAfterSalesPhone();
    /**
     * 根据用户Id修改密码
     * @param password 密码
     * @param userId   用户Id
     */
    void updatePasswordByUserId(String password, Integer userId);
    /**
     * 根据用户Id修改手机号
     * @param mobile   手机号
     * @param userId   用户Id
     */
    void updateMobileByUserId(String mobile, Integer userId);
    /**
     * 根据用户Id修改头像
     * @param image   头像
     * @param userId   用户Id
     */
    void updateImageByUserId(String image, Integer userId);
    /**
     * 根据供应商Id修改手机号
     * @param mobile   手机号
     * @param shopId   用户Id
     */
    void updateShopMobileByShopId(String mobile, Integer shopId);
    /**
     * 根据机构Id修改手机号
     * @param mobile   手机号
     * @param clubId   用户Id
     */
    void updateClubMobileByClubId(String mobile, Integer clubId);

    /**
     * 查询敏感词
     */
    String getSensitiveWords(Integer checkPoint);

    List<String> findLabelsByLableIds(String labelIds);

    Integer findBankByUserId(Integer userId);

    Integer getByUserId(@Param("userType") Integer userType, @Param("id") Integer id);

    String getByMobile(@Param("userIdentity") Integer userIdentity, @Param("userId") Integer userId);

    Integer getByUserCount(CmUser user);

    /**
     * 新增用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int addUser(CmUser user);

    /**
     * 修改用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUser(CmUser user);


    /**
     * 修改机构状态信息
     *
     */
    public int updateClubStatus(Integer userId,Integer status);

    public int getUserType(String userId);

    /**
     * 用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public CmUser getByUser(CmUser user);

    public List<String> findAdminMobileList(Integer type);

    CmUser findUserByMobile(@Param("mobile") String mobile, @Param("oldUserId") Integer oldUserId, @Param("userIdentity") Integer userIdentity);
    /**
     * 新增unionid与不同应用的openid关系
     */
    int addWxUnion(@Param("type") Integer type,@Param("openid")String openid,@Param("unionId")String unionId);

    /**
     * 修改unionid与不同应用的openid关系
     */
    int updateWxUnion(@Param("type") Integer type,@Param("openid")String openid,@Param("unionId")String unionId);
    /**
     * 通过对象查询unionid与不同应用的openid关系对象
     */
    WxUnion getByWxUnion(@Param("type") Integer type,@Param("openid")String openid,@Param("unionId")String unionId);

    /**
     * 通过对象查询相关图片列表
     * @param cmRelatedImage 相关图片
     * @return 相关图片集合
     */
    List<String> getRelatedImageList(CmRelatedImage cmRelatedImage);

    Integer findTicket(String s);

    void insertTicket(String s);
}
