package com.caimei365.user.mapper;

import java.util.List;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.po.CmDistribution;
import com.caimei365.user.model.vo.UserLoginVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * distributionMapper接口
 *
 * @author Kaick
 * @date 2023-09-25
 */
@Mapper
public interface CmDistributionMapper
{
    /**
     * 通过对象查询distribution列表
     *
     * @param cmDistribution distribution
     * @return distribution集合
     */
    public List<CmDistribution> getCmDistributionList(CmDistribution cmDistribution);

    /**
     * 通过Id查询distribution对象
     *
     * @param id distribution主键
     * @return distribution
     */
    public CmDistribution getCmDistributionById(String id);

    /**
     * 通过对象查询distribution对象
     *
     * @param cmDistribution distribution
     * @return distribution
     */
    public CmDistribution getByCmDistribution(CmDistribution cmDistribution);

    /**
     * 通过对象查询distributionId
     *
     * @param cmDistribution distribution
     * @return String
     */
    public String getById(CmDistribution cmDistribution);

    /**
     * 通过对象查询distributionIds
     *
     * @param cmDistribution distribution
     * @return List<String>
     */
    public List<String> getByIds(CmDistribution cmDistribution);

    /**
     * 通过对象查询distribution记录总数
     *
     * @param cmDistribution distribution
     * @return distributionInteger
     */
    public int getCmDistributionCount(CmDistribution cmDistribution);

    /**
     * 根据手机号获取协销
     *
     * @param mobile 手机号
     * @return UserLoginVo
     */
    UserLoginVo getLoginDistributionByMobile(String mobile);
    /**
     * 新增distribution
     *
     * @param cmDistribution distribution
     * @return 结果
     */
    public int addCmDistribution(CmDistribution cmDistribution);

    /**
     * 修改distribution
     *
     * @param cmDistribution distribution
     * @return 结果
     */
    public int updateCmDistribution(CmDistribution cmDistribution);

    /**
     * 删除distribution
     *
     * @param id distribution主键
     * @return 结果
     */
    public int delCmDistributionById(String id);

    /**
     * 批量删除distribution
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmDistribution(CmDistribution cmDistribution);

    /**
     * 批量删除distribution
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmDistributionByIds(@Param("ids") String[] ids);

    /**
     * 修改批量删除distribution
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int updateDelCmDistributionByIds(@Param("ids") String[] ids,@Param("delFlag") Integer delFlag);
}
