package com.caimei365.user.mapper;

import com.caimei365.user.model.po.ShopSignPo;
import com.caimei365.user.model.po.TicketPo;
import com.caimei365.user.model.vo.LoginFailRecordVo;
import com.caimei365.user.model.vo.OperationVo;
import com.caimei365.user.model.vo.ServiceProviderVo;
import com.caimei365.user.model.vo.UserLoginVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/5
 */
@Mapper
public interface LoginMapper {
    /**
     * 根据用户id获取用户
     *
     * @param userId 手机号
     * @return baseuser
     */
    UserLoginVo getLoginUserByUserId(@Param("userId") Integer userId);

    /**
     * 根据手机号或邮箱获取用户
     *
     * @param mobileOrEmail 手机号/邮箱
     * @return BaseUser
     */
    UserLoginVo getLoginUserByMobileOrEmail(@Param("mobileOrEmail") String mobileOrEmail);

    /**
     * 根据手机号或邮箱获取用户
     *
     * @param mobileOrEmail 手机号/邮箱
     * @return BaseUser
     */
    UserLoginVo getLoginOrganizeUserByMobileOrEmail(@Param("mobileOrEmail") String mobileOrEmail);

    /**
     * 是否绑定微信
     *
     * @param mobileOrEmail
     * @return
     */
    Integer getOperationUser(@Param("mobileOrEmail") String mobileOrEmail);

    /**
     * 绑定微信
     *
     * @param operationVo
     */
    void insertOperation(OperationVo operationVo);

    /**
     * 根据手机号获取用户
     *
     * @param mobile 手机号/邮箱
     * @return BaseUser
     */
    UserLoginVo getLoginUserByMobile(@Param("mobile") String mobile, @Param("organizeId") Integer organizeId);

    /**
     * 根据openId获取协销
     *
     * @param openId openId
     * @return BaseUser
     */
    UserLoginVo getServiceProviderUserByOpenId(@Param("openId") String openId, @Param("organizeId") Integer organizeId);

    /**
     * 根据用户ID更新协销unionId
     *
     * @param userId
     * @param unionId
     */
    void updateServiceProviderUnionId(@Param("userId") Integer userId, @Param("unionId") String unionId);

    /**
     * 供应商商品上架平台属性
     *
     * @param shopId
     * @return
     */
    List<String> getShopProductGroudMall(@Param("shopId") Integer shopId);

    /**
     * 修改用户微信授权信息
     *
     * @param openId
     * @param unionId
     * @param userId
     */
    void updateUserInfo(@Param("openId") String openId, @Param("unionId") String unionId, @Param("userId") Integer userId);

    /**
     * 根据userId获取协销
     *
     * @param userId
     * @return
     */
    ServiceProviderVo getServiceProviderByUserId(Integer userId);

    /**
     * 根据unionId获取运营人员
     *
     * @param unionId unionId
     * @param source
     * @return BaseUser
     */
    UserLoginVo getLoginUserByUnionId(@Param("unionId") String unionId, @Param("source") String source);

    /**
     * 根据unionId获取运营人员 -- 组织
     *
     * @param unionId unionId
     * @param source
     * @return BaseUser
     */
    UserLoginVo getOrganizeLoginUserByUnionId(@Param("unionId") String unionId, @Param("source") String source);

    /**
     * 根据openId获取运营人员
     *
     * @param openId
     * @param source
     * @return
     */
    UserLoginVo getLoginUserByOpenId(@Param("openId") String openId, @Param("source") String source);

    /**
     * 根据openId获取运营人员 -- 组织
     *
     * @param openId
     * @param source
     * @return
     */
    UserLoginVo getOrganizeLoginUserByOpenId(@Param("openId") String openId, @Param("source") String source);

    /**
     * 根据邀请码获取运营人员
     *
     * @param invitationCode
     * @return
     */
    UserLoginVo getOperationUserByInvitationCode(String invitationCode, Integer organizeId);

    /**
     * 根据邀请码获取运营人员 -- 组织
     *
     * @param invitationCode
     * @param organizeId
     * @return
     */
    UserLoginVo getOperationOrganizeUserByInvitationCode(String invitationCode, Integer organizeId);

    /**
     * 根据Id获取运营人员用户信息（关联user）
     *
     * @param operationId 用户Id
     * @return
     */
    UserLoginVo getOperationUserByOperationId(Integer operationId);

    /**
     * 根据Id、组织Id 获取运营人员用户信息（关联user）
     *
     * @param operationId
     * @param organizeId
     * @return
     */
    UserLoginVo getOrganizeByOperationId(@Param("operationId") Integer operationId, @Param("organizeId") Integer organizeId);

    /**
     * 根据openId获取用户Id
     *
     * @param openId
     * @param source
     * @return
     */
    Integer getUserIdByOpenId(@Param("openId") String openId, @Param("source") String source);

    /**
     * 根据机构名称获取机构数量
     *
     * @param clubName 机构名称
     * @return Integer
     */
    Integer getClubCountByClubName(String clubName);

    /**
     * 获取最大的用户Id
     *
     * @return
     */
    Integer getMaxClubId();

    /**
     * 获取最大的机构Id
     *
     * @return
     */
    Integer getMaxUserId();

    /**
     * 记录登录时间
     *
     * @param userId
     */
    void updateLogin(Integer userId);


    /**
     * 会员机构类型：1医美，2生
     */
    Integer getClubTypeById(Integer userId);

    /**
     * 会员机构类型：1医美，2生
     */
    Integer getClubSpUserId(Integer clubId);

    /**
     * 关联用户和游客
     *
     * @param userId
     * @param touristId
     */
    void updateTourist(@Param("userId") Integer userId, @Param("touristId") String touristId);

    String findTemPass(Integer userId);

    TicketPo findTicket(String ticket);

    void updateTicket(@Param("userId") Integer userId, @Param("idCard") String idCard, @Param("ticket") String ticket,
                      @Param("name") String name, @Param("mobile") String mobile, @Param("work") String work, @Param("shopIds") String shopIds);

    TicketPo findTicketUser(Integer userId);

    String findShopSign(Integer userId);

    void updateShopSign(@Param("userId") Integer userId, @Param("shopSign") String shopSign);

    List<ShopSignPo> findShopSignPos(Integer userId);

    ShopSignPo findShopDetail(@Param("shopId") Integer shopId, @Param("userId") Integer userId);

    void insertTicket(@Param("userId") Integer userId, @Param("shopSign") String shopSign);

    void deleteTicketUser(Integer userId);
}
