package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.OperationDto;
import com.caimei365.user.model.po.OperationPo;
import com.caimei365.user.model.vo.OperationVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/26
 */
@Mapper
public interface OperationMapper {
    /**
     * 根据手机号获取运营人员
     *
     * @param mobile 手机号
     * @return BaseUser
     */
    OperationPo getOperationByMobile(@Param("mobile") String mobile);
    /**
     * 根据用户ID更新运营人员openId
     * @param userId
     * @param openId
     */
    void updateOperationOpenId(@Param("userId") Integer userId, @Param("openId") String openId);
    /**
     * 根据用户ID更新运营人员unionId
     * @param userId
     * @param unionId
     */
    void updateOperationUnionId(@Param("userId") Integer userId, @Param("unionId") String unionId);

    /**
     * 邀请码登录更新运营人员信息
     * @param operationPo 运营人员信息
     */
    void updateOperationByInvitation(OperationPo operationPo);

    /**
     * 解绑更新运营人员信息
     * @param operation 运营人员信息
     */
    int updateOperationByUnbind(OperationPo operation);

    /**
     * 统计生成随机码是否和数据库有重复
     */
    int countByInvitationCode(String invitationCode);
    /**
     * 查找机构名称
     */
    String findClubNameById(Integer clubId);
    /**
     * 查找供应商名称
     */
    String findShopNameById(Integer shopId);
    /**
     * 根据手机号查询运营人员信息
     * @param mobile
     * @param organizeId
     * @return
     */
    OperationPo getInfoByMobile(@Param("mobile") String mobile, @Param("organizeId") Integer organizeId);
    /**
     * 新增运营人员
     */
    int insertOperation(OperationPo operation);
    /**
     * 更新运营人员
     */
    int updateOperation(OperationPo operation);
    /**
     * 根据id获取运营人员邀请码信息
     */
    OperationPo getOperationCodeInfoById(Integer id);

    /**
     * 获取运营人员列表
     */
    List<OperationVo> getOperationListByUserId(Integer userId, String mobile, String linkName);
}
