package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.dto.TaskPushDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
@Mapper
public interface SellerMapper {
    /**
     * 根据手机号获取协销
     *
     * @param mobile 手机号
     * @return UserLoginVo
     */
    UserLoginVo getLoginSellerByMobile(String mobile);

    /**
     * 更新协销
     *
     * @param userId
     * @param openId
     * @param unionId
     */
    void updateServiceProviderByUserId(Integer userId, String openId, String unionId);

    /**
     * 更新协销信息
     */
    Integer setSellerHome(ServiceProviderPo serviceProviderPo);
    /**
     * 更新协销头像
     */
    Integer setSellerUserHome(@Param("userId")Integer userId, @Param("image")String image);

    /**
     * 查询待注册机构数据
     *
     * @param userId
     * @param searchName
     * @return
     */
    List<ClubTemporaryVo> findClubTemporary(@Param("userId") Integer userId, @Param("searchName") String searchName);

    /**
     * 修改待注册机构数据
     *
     * @param temporaryDto
     */
    void updateClubTemporary(ClubTemporaryDto temporaryDto);

    /**
     * 删除待注册机构数据
     *
     * @param id
     */
    void deleteTemporaryClub(Integer id);

    /**
     * 机构数据
     * @param serviceProviderId
     * @param status
     * @param name
     * @param userIdentity
     * @param type
     * @param startTime
     * @param endTime
     * @param activeState
     * @param customerValue
     * @param serviceIds
     * @return
     */
    List<ClubVo> findClubs(@Param("serviceProviderId") Integer serviceProviderId, @Param("status") Integer status, @Param("name") String name,
                           @Param("userIdentity") Integer userIdentity, @Param("type") Integer type, @Param("startTime") String startTime,
                           @Param("endTime") String endTime, @Param("activeState") String activeState,@Param("customerValue") String customerValue,
                           @Param("serviceIds") List<Integer> serviceIds);

    /**
     * 获取相关咨询记录机构信息
     * @param spId
     * @param type
     * @return
     */
    List<ClubVo> getIsRemarkClub(@Param("spId") Integer spId, @Param("type") Integer type);

    /**
     * 机构所有咨询记录
     * @param clubId
     * @return
     */
    List<RemarksVo> getClubAllRemark(@Param("clubId") Integer clubId, @Param("search") String search);

    /***
     * 功能描述: 机构活跃分析用户登录数量
     * @auther: Kaick
     * @date: 2023/8/30 15:25
     * @param spId
     * @return [spID]
     */
    List<Map<String, Object>> findSpUserLoginSum(@Param("spId") Integer spId);

    /**
     * 协销下填写过咨询记录的机构
     * @param spId
     * @return
     */
    Map<String, Object> getRemarkClub(@Param("spId") Integer spId);

    Integer findOrderNum(ClubVo club);

    /**
     * 所有的机构列表
     */
    List<ClubVo> getAllClubList(String searchWord);

    /**
     * 协销信息
     */
    ServiceProviderPo getSellerByUserId(Integer userId);

    Integer findManager(String mobile);

    Integer findManagerByUser(Integer userId);

    Integer findLeaderId(Integer userId);

    Integer findLeaderIdByServiceId(Integer serviceProviderId);

    Integer findmanagerIdByServiceId(Integer serviceProviderId);

    List<Integer> findServiceIds(Integer serviceProviderId);

    List<Integer> findAllServiceIds(Integer serviceProviderId);

    List<ServiceProviderVo> findServices(@Param("spId")Integer spId,@Param("status")Integer status);

    List<ServiceProviderVo> findAllServices(@Param("spId")Integer spId,@Param("status")Integer status);

    String getBehaviorRecordYesterdayPageLabel(@Param("spId") Integer spId,@Param("clubId") Integer clubId,@Param("accessTime")String accessTime);
    String getBehaviorRecordMinutePageLabel(@Param("spId") Integer spId,@Param("clubId") Integer clubId,@Param("accessTime")String accessTime);

    List<CmBehaviorRecordVo> getBehaviorRecordYesterdayClubFrom(@Param("spId") Integer spId, @Param("clubId") Integer clubId, @Param("accessTime")String accessTime);
    List<CmBehaviorRecordVo> getBehaviorRecordMinuteClubFrom(@Param("spId") Integer spId, @Param("clubId") Integer clubId, @Param("accessTime")String accessTime);

    List<CmBehaviorRecordVo> getBehaviorRecordYesterdayClub(@Param("spId") Integer spId,@Param("accessTime")String accessTime);

    List<CmBehaviorRecordVo> getBehaviorRecordMinuteClub(@Param("spId") Integer spId,@Param("accessTime")String accessTime);

    /**
     * 获取机构有访问记录的日期
     * @param clubId
     * @return
     */
    List<RetuenDataVo> getClubAccessDate(@Param("clubId") Integer clubId);

    /**
     * 访问详情
     * @param clubId
     * @param accessDateList
     * @return
     */
    List<BehaviorRecodeVo> getClubKeynoteRecord(@Param("clubId") Integer clubId, @Param("accessDateList") List<String> accessDateList);
    /**
     * 协销不活跃机构列表
     * @param serviceProviderId
     * @return
     */
    List<ClubVo> getUnActiveClub(@Param("serviceProviderId") Integer serviceProviderId);

    List<ProviderTaskVo> getTaskList(@Param("serviceProviderId") Integer serviceProviderId, @Param("taskType") Integer taskType);

    void receiveTask(@Param("serviceProviderId") Integer serviceProviderId, @Param("taskId") Integer taskId);

    ProviderTaskVo getTaskDetail(Integer taskId);

    void insertClick(@Param("serviceProviderId") Integer serviceProviderId, @Param("userId") Integer userId, @Param("taskId") Integer taskId, @Param("ip") String ip);

    void insertTaskAudit(TaskPushDto dto);

    void insertTaskImages(TaskPushDto dto);

    void updateTaskAudit(TaskPushDto dto);

    List<ShopTaskVo> getShopTaskList(Integer shopId);

    ProviderTaskVo getProviderTaskDetail(@Param("taskId") Integer taskId, @Param("serviceProviderId") Integer serviceProviderId);

    void deleteTaskImages(TaskPushDto dto);
}
