package com.caimei365.user.mapper;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.po.SuperVipPo;
import com.caimei365.user.model.po.VipPackage;
import com.caimei365.user.model.po.VipPayHistoryPo;
import com.caimei365.user.model.vo.CouponVo;
import com.caimei365.user.model.vo.ProductItemVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author zzj
 */
@Mapper
public interface SuperVipMapper {

    /**
     * 超级会员每个月卷
     *
     * @param userId 机构用户id
     * @param useTime 当月月份
     * @return
     */
    List<CouponVo> findVipCoupon(Integer userId, String useTime);

    /**
     * 查当月优惠券是否被领取
     * @param userId
     * @return
     */
    List<Integer> findCouponGet(@Param("userId") Integer userId,String useTime);
    /**
     * 查vip信息
     *
     * @param userId
     * @return
     */
    SuperVipPo findSuperVip(Integer userId);

    /**
     * vip过期推送
     */
    List<SuperVipPo> findVip();

    /**
     * 查用户名下采美豆余额
     *
     * @param userId
     * @return
     */
    Integer findUserBeans(Integer userId);

    /**
     * user表修改采美豆数量
     *
     * @param userId
     * @param userBeans
     */
    void updateUserBeans(Integer userId, Integer userBeans);

    /**
     * 采美豆历史表更改
     *
     * @param userId
     * @param userBeans
     */
    void addUserBeansHistory(Integer userId, Integer userBeans);


    /**
     * 用户身份修改
     * 用户身份 0、个人 1、协销 2、会员机构 3、供应商 4.普通机构 6、颜选美学商城用户【V6.2.0版本后0不存在】
     *
     * @param userId
     * @param userIdentity
     */
    void updateUserIdentity(Integer userId, Integer userIdentity);

    /**
     * 查套餐详情
     * @param userPackageId
     * @return
     */
    VipPackage findUserPackage(Integer userPackageId);

    /**
     * 新增支付记录
     *
     * @param payHistory
     */
    int addPayHistory(VipPayHistoryPo payHistory);

    void updatePayHistory(VipPayHistoryPo payHistory);

    /**
     * 根据套餐id查套餐时间
     *
     * @param userPackageId
     * @return
     */
    Integer findUserPackageTime(Integer userPackageId);

    /**
     * 超级会员表加数据
     * @param superVip
     */
    void addVip(SuperVipPo superVip);

    /**
     * 修改超级会员表
     * @param superVip
     */
    void updateVip(SuperVipPo superVip);

    /**
     * 查超级会员购买记录
     * @param userId
     * @return
     */
    List<VipPayHistoryPo> findVipHistory(@Param("userId") Integer userId);

    /**
     * 查会员是否过期
     * @param userId
     * @return
     */
    SuperVipPo findEndTime(Integer userId);

    /**
     * 找手机号发短信
     * @param userId
     * @return
     */
    String findMobile(Integer userId);

    /**
     * 套餐详情
     * @return
     */
    List<VipPackage> findPackage();
    /**
     * 查询未支付的当前超级会员套餐购买记录
     */
    Integer getVipHistoryId(Integer userId, Integer packageId);

    /**
     * 查是否有已使用的超级会员优惠券
     * @param userId
     * @param useTime
     * @return
     */
    List<Integer> findCouponUse(@Param("userId") Integer userId,@Param("useTime")String useTime);

    Integer findBYShortLink(String shortLink);

    void insertShortLink(int markId, String shortLink, String url);
}
