package com.caimei365.user.model.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Data;
import lombok.experimental.Accessors;

import java.util.List;

@Data
@Accessors(fluent = true)
public class ApiRequest {

    /**
     * 百度千帆大模型ERNIE-3.5-8K
     * https://cloud.baidu.com/doc/WENXINWORKSHOP/s/Olvlzrruq
     */

    @JsonProperty("messages")
    private List<Message> messages;

    /**
     * 是否强制关闭实时搜索功能，默认false，表示不关闭
     */
    @JsonProperty("disable_search")
    private boolean disableSearch;

    /**
     * 是否以流式接口的形式返回数据，默认false
     */
    @JsonProperty("stream")
    private boolean stream;

    /**
     * 温度 0.6
     * 说明：
     * （1）影响输出文本的多样性，取值越大，生成文本的多样性越强
     * （2）默认0.8，取值范围 [0, 1.0]
     */
    @JsonProperty("top_p")
    private Double top_p;

    /**
     * 重复惩罚值 1.5
     * 通过对已生成的token增加惩罚，减少重复生成的现象。说明：
     * （1）值越大表示惩罚越大
     * （2）默认1.0，取值范围：[1.0, 2.0]
     */
    @JsonProperty("penalty_score")
    private Double penaltyScore;

    /**
     * 搜索溯源
     */
    @JsonProperty("enable_citation")
    private boolean enableCitation;


    /**
     * 搜索溯源
     */
    @JsonProperty("enable_trace")
    private boolean enableTrace;

    @Data
    @Accessors(fluent = true)
    public static class Message {
        @JsonProperty("role")
        private String role;

        @JsonProperty("content")
        private String content;

    }
}