package com.caimei365.user.service;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.dto.LoginCodeDto;
import com.caimei365.user.model.dto.TaskPushDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.*;
import com.github.pagehelper.PageInfo;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
public interface SellerService {

    /**
     * 协销机构列表
     *
     * @param serviceProviderId 协销Id
     * @param status            机构状态
     * @param name              机构名字关键字（搜索用）
     * @return
     */
    ResponseJson<PageInfo<ClubVo>> getClubList(Integer serviceProviderId, Integer status, Integer type, String name, Integer userIdentity, Integer groupServiceId, String startTime, String endTime, String activeState, String customerValue, Integer pageNum, Integer pageSize);

    /**
     * 功能描述: 机构活跃分析
     *
     * @param serviceProviderId
     * @param status
     * @param type
     * @param name
     * @param userIdentity
     * @param pageNum
     * @param pageSize
     * @return [serviceProviderId, status, type, name, userIdentity, pageNum, pageSize]
     * @auther: Kaick
     * @date: 2023/8/30 16:54
     */
    ResponseJson<PaginationVo<ClubVo>> getLivelyClubList(Integer serviceProviderId, Integer status, Integer type, String name, Integer userIdentity, Integer pageNum, Integer pageSize);

    /**
     * 获取相关咨询记录机构信息
     *
     * @param spId
     * @param type
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<ClubVo>> getIsRemarkClub(Integer spId, Integer type, Integer pageNum, Integer pageSize);

    /**
     * 机构所有的咨询记录
     *
     * @param clubId
     * @return
     */
    ResponseJson<PaginationVo<RemarksVo>> getClubAllRemark(Integer clubId, String search, Integer pageNum, Integer pageSize);

    /**
     * 功能描述: 机构活跃分析比例
     *
     * @param
     * @return []
     * @auther: Kaick
     * @date: 2023/9/4 9:48
     */

    ResponseJson<Map<String, Object>> getLivelyClub(Integer serviceProviderId);

    /**
     * 协销登录(手机号，密码)
     *
     * @param mobile   手机号
     * @param password 密码
     * @param unionId  微信unionId
     * @return UserLoginVo
     */
    ResponseJson<UserLoginVo> passwordLogin(String mobile, String password, String unionId, Integer isUnion);

    /**
     * 采购员验证码登录 --组织
     *
     * @param loginCodeDto
     * @return
     */
    ResponseJson<UserLoginVo> organizeCodeLogin(LoginCodeDto loginCodeDto);

    /**
     * 待注册机构列表
     *
     * @param userId     协销用户id
     * @param searchName 搜索名称
     * @param pageNum    第几页
     * @param pageSize   一页多少条
     * @return ClubTemporaryVo
     */
    ResponseJson<PageInfo<ClubTemporaryVo>> temporaryClub(Integer userId, String searchName, Integer pageNum, Integer pageSize);

    /**
     * 修改待注册机构资料
     *
     * @param temporaryDto
     * @return
     */
    ResponseJson<String> modifyTemporaryClub(ClubTemporaryDto temporaryDto);

    /**
     * 删除待注册机构资料
     *
     * @param id 暂存数据id
     * @return
     */
    ResponseJson<String> deleteTemporaryClub(Integer id);

    /**
     * 所有的机构列表
     *
     * @param searchWord 搜索关键字
     */
    ResponseJson<PageInfo<ClubVo>> getAllClubList(String searchWord, int pageNum, int pageSize);

    /**
     * 协销个人中心
     *
     * @param userId 协销用户id
     */
    ResponseJson<ServiceProviderPo> getSellerHome(Integer userId);

    /**
     * 功能描述: 更新协销信息
     *
     * @param serviceProviderPo
     * @return [serviceProviderPo]
     * @auther: Kaick
     * @date: 2023/9/4 10:02
     */

    ResponseJson setSellerHome(ServiceProviderPo serviceProviderPo);

    ResponseJson<List<CmBehaviorRecordVo>> getBehaviorRecordClub(Integer type, Integer spId, String accessTime);

    ResponseJson<List<CmBehaviorRecordVo>> getBehaviorRecordClubFrom(Integer type, Integer spId, Integer clubId, String accessTime);

    ResponseJson<List<ServiceProviderVo>> getServiceTeam(Integer spId, Integer status);

    /**
     * 机构重点访问页面
     *
     * @param clubId
     * @return
     */
    ResponseJson<PageInfo<RetuenDataVo>> getClubRecord(Integer clubId, int pageNum, int pageSize);

    /**
     * 协销不活跃机构列表
     *
     * @param serviceProviderId
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PageInfo<ClubVo>> getUnActiveClubList(Integer serviceProviderId, int pageNum, int pageSize);

    ResponseJson<PageInfo<ProviderTaskVo>> getTaskList(Integer serviceProviderId, Integer taskType, int pageNum, int pageSize);

    ResponseJson receiveTask(Integer serviceProviderId, Integer taskId);

    ResponseJson<ProviderTaskVo> getTaskDetail(HttpServletRequest request, Integer taskId, Integer serviceProviderId, Integer userId);

    ResponseJson taskAudit(TaskPushDto dto);

    ResponseJson<PageInfo<ShopTaskVo>> getShopTaskList(Integer shopId, int pageNum, int pageSize);

    ResponseJson<ProviderTaskVo> getProviderTaskDetail(Integer taskId, Integer serviceProviderId);
}
