package com.caimei365.user.service.impl;

import com.caimei365.user.components.RedisService;
import com.caimei365.user.components.WeChatService;
import com.caimei365.user.mapper.*;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.dto.LoginCodeDto;
import com.caimei365.user.model.dto.TaskPushDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.po.SuperVipPo;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.SellerService;
import com.caimei365.user.utils.ImageUtils;
import com.caimei365.user.utils.JwtUtil;
import com.caimei365.user.utils.MathUtil;
import com.caimei365.user.utils.Md5Util;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
@Slf4j
@Service
public class SellerServiceImpl implements SellerService {
    @Value("${caimei.wwwDomain}")
    private String wwwDomain;
    @Resource
    private RedisService redisService;
    @Resource
    private WeChatService weChatService;
    @Resource
    private SellerMapper sellerMapper;
    @Resource
    private ShopMapper shopMapper;
    @Resource
    private ArticleMapper articleMapper;
    @Resource
    private SuperVipMapper vipMapper;
    @Resource
    private LoginMapper loginMapper;
    @Resource
    private ClubMapper clubMapper;
    @Resource
    private AsyncService asyncService;

    /**
     * 协销机构列表
     *
     * @param serviceProviderId 协销Id
     * @param status            机构状态:
     *                          1:待审查资料, 2:电话预约, 3:已预约
     *                          20:待确认, 21:待拜访, 30:待员工推荐
     *                          90:已上线, 91:已冻结, 92:审查资料未通过,待补充资料, 40:已完成第一次采购
     *                          66:协销下所有上线的机构----虚拟状态
     * @param name              机构名字关键字（搜索用）
     * @param type              1.我的机构2.组员机构(组长展示全组，总管理员展示所有人)3.待分配机构
     * @return
     */
    @Override
    public ResponseJson<PageInfo<ClubVo>> getClubList(Integer serviceProviderId, Integer status, Integer type, String name, Integer userIdentity, Integer groupServiceId, String startTime, String endTime, String activeState, String customerValue, Integer pageNum, Integer pageSize) {
        // 处理时间格式
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
        try {
            if (StringUtils.isNotBlank(startTime)) {
                String start = dateFormat.format(dateFormat.parse(startTime));
                startTime = start + " 00:00:00";
            }
            if (StringUtils.isNotBlank(endTime)) {
                String end = dateFormat.format(dateFormat.parse(endTime));
                endTime = end + " 23:59:59";
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        // 获取协销用户下的机构列表
        List<ClubVo> clubList = new ArrayList<ClubVo>();
        List<Integer> serviceIds = new ArrayList<Integer>();
        if (1 == type || 3 == type || 6 == type) {
            if (null != groupServiceId && groupServiceId > 0) {
                return ResponseJson.success();
            } else {
                PageHelper.startPage(pageNum, pageSize);
                clubList = sellerMapper.findClubs(serviceProviderId, status, name, userIdentity, type, startTime, endTime, activeState, customerValue, null);
            }
        } else if (2 == type) {
            if (null != groupServiceId && groupServiceId > 0) {
                PageHelper.startPage(pageNum, pageSize);
                clubList = sellerMapper.findClubs(groupServiceId, status, name, userIdentity, 1, startTime, endTime, activeState, customerValue, null);
            } else {
                Integer leaderId = sellerMapper.findLeaderIdByServiceId(serviceProviderId);
                Integer managerId = sellerMapper.findmanagerIdByServiceId(serviceProviderId);
                if (null != leaderId) {
                    serviceIds = sellerMapper.findServiceIds(serviceProviderId);
                }
                if (null != managerId) {
                    serviceIds = sellerMapper.findAllServiceIds(serviceProviderId);
                }
                PageHelper.startPage(pageNum, pageSize);
                clubList = sellerMapper.findClubs(serviceProviderId, status, name, userIdentity, type, startTime, endTime, activeState, customerValue, serviceIds);
            }
        }
        for (ClubVo club : clubList) {
            //未查看订单数量
            Integer orderNum = sellerMapper.findOrderNum(club);
            club.setOrderNum(orderNum);
            //查是不是vip
            SuperVipPo vip = vipMapper.findEndTime(club.getUserId());
            if (vip != null) {
                club.setVipFlag(1);
            } else {
                club.setVipFlag(0);
            }
            setClubNumber(club);
        }
        PageInfo<ClubVo> pageData = new PageInfo<>(clubList);
        return ResponseJson.success(pageData);
    }

    /**
     * 机构活跃分析
     *
     * @param serviceProviderId 协销Id
     * @param status            机构状态:
     *                          1:待审查资料, 2:电话预约, 3:已预约
     *                          20:待确认, 21:待拜访, 30:待员工推荐
     *                          90:已上线, 91:已冻结, 92:审查资料未通过,待补充资料, 40:已完成第一次采购
     *                          66:协销下所有上线的机构----虚拟状态
     * @param name              机构名字关键字（搜索用）
     * @param type              1.我的机构2.组员机构(组长展示全组，总管理员展示所有人)3.待分配机构
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<ClubVo>> getLivelyClubList(Integer serviceProviderId, Integer status, Integer type, String name, Integer userIdentity, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ClubVo> clubList = sellerMapper.findClubs(serviceProviderId, status, name, userIdentity, type, null, null, null, null, null);
        if (null != clubList) {
            for (ClubVo club : clubList) {
                // 添加编号
                String newClubId = club.getClubId().toString();
                if (newClubId.length() <= 6) {
                    for (int i = 0; i <= 6 - newClubId.length(); i++) {
                        newClubId = "0" + newClubId;
                    }
                }
                club.setNewClubId(newClubId);
            }
        }
        PaginationVo<ClubVo> page = new PaginationVo<>(clubList);
        return ResponseJson.success(page);
    }

    /**
     * 获取相关咨询记录机构信息
     *
     * @param spId
     * @param type
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<ClubVo>> getIsRemarkClub(Integer spId, Integer type, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ClubVo> remarkClub = sellerMapper.getIsRemarkClub(spId, type);
        if (null != remarkClub) {
            for (ClubVo club : remarkClub) {
                // 添加编号
                String newClubId = club.getClubId().toString();
                if (newClubId.length() <= 6) {
                    for (int i = 0; i <= 6 - newClubId.length(); i++) {
                        newClubId = "0" + newClubId;
                    }
                }
                club.setNewClubId(newClubId);
            }
        }
        PaginationVo<ClubVo> page = new PaginationVo<>(remarkClub);
        return ResponseJson.success(page);
    }

    /**
     * 机构所有的咨询记录
     *
     * @param clubId
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<RemarksVo>> getClubAllRemark(Integer clubId, String search, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<RemarksVo> clubAllRemark = sellerMapper.getClubAllRemark(clubId, search);

        clubAllRemark.forEach(remark -> {
            // 标签集合
            List<Map<String, String>> labelMap = new ArrayList<>();
            Map<String, String> map;
            // 备注
            String label = remark.getRemarks();
            if (label.contains(",")) {
                String[] split = label.split(",");
                for (String str : split) {
                    map = new HashMap<>();
                    map.put("label", str);
                    labelMap.add(map);
                }
            } else {
                map = new HashMap<>();
                map.put("label", label);
                labelMap.add(map);
            }
            // 动态标签
            String trend = remark.getTrendsKeyword();
            if (trend.contains(",")) {
                String[] split = trend.split(",");
                for (String str : split) {
                    map = new HashMap<>();
                    map.put("label", str);
                    labelMap.add(map);
                }
            } else {
                map = new HashMap<>();
                map.put("label", trend);
                labelMap.add(map);
            }
            // 静态标签
            String state = remark.getStateKeyword();
            if (state.contains(",")) {
                String[] split = state.split(",");
                for (String str : split) {
                    map = new HashMap<>();
                    map.put("label", str);
                    labelMap.add(map);
                }
            } else {
                map = new HashMap<>();
                map.put("label", state);
                labelMap.add(map);
            }
            remark.setRemarkLabel(labelMap);
        });

        PaginationVo<RemarksVo> page = new PaginationVo<>(clubAllRemark);
        return ResponseJson.success(page);
    }

    /**
     * 功能描述: 机构活跃分析比例
     *
     * @param
     * @return []
     * @auther: Kaick
     * @date: 2023/9/4 9:48
     */

    @Override
    public ResponseJson<Map<String, Object>> getLivelyClub(Integer serviceProviderId) {
        Map<String, Object> map = new HashMap<>();
        // 该协销下活跃用户数据
        List<Map<String, Object>> spUserLoginSum = sellerMapper.findSpUserLoginSum(serviceProviderId);
        if (null != spUserLoginSum) {
            // 活跃机构数
            Integer activeNumber = 0;
            // 不活跃机构数
            Integer unActiveNumber = 0;
            // 总数
            Integer total = 0;
            ArrayList<PortraitMap> portraitMap = new ArrayList<>();
            for (Map<String, Object> objectMap : spUserLoginSum) {
                if (objectMap.get("activeStatus").equals("active")) {
                    activeNumber = Integer.valueOf(objectMap.get("number").toString());
                } else {
                    unActiveNumber = Integer.valueOf(objectMap.get("number").toString());
                }
            }
            total = activeNumber + unActiveNumber;
            if (0 == total) {
                return ResponseJson.success(null);
            }
            // 机构活跃
            PortraitMap portrait = new PortraitMap();
            String per = MathUtil.mul(MathUtil.div(activeNumber, total, 2), 100).toString();
            portrait.setName("活跃机构");
            portrait.setValue(activeNumber);
            portrait.setPer(per);
            portraitMap.add(portrait);
            // 机构不活跃
            portrait = new PortraitMap();
            per = MathUtil.mul(MathUtil.div(unActiveNumber, total, 2), 100).toString();
            portrait.setName("不活跃机构");
            portrait.setValue(unActiveNumber);
            portrait.setPer(per);
            portraitMap.add(portrait);
            map.put("portraitMap", portraitMap);
        }
        Map<String, Object> remarkClub = sellerMapper.getRemarkClub(serviceProviderId);
        if (null != remarkClub) {
            // 有咨询记录的机构数
            Integer isHaveClub = Integer.valueOf(remarkClub.get("isHaveClub").toString());
            // 总机构数
            Integer allclub = Integer.valueOf(remarkClub.get("allclub").toString());
            // 没有有咨询记录的
            Integer number = allclub - isHaveClub;
            // 有咨询记录
            ArrayList<PortraitMap> portraitMap = new ArrayList<>();
            PortraitMap portrait = new PortraitMap();
            String per = MathUtil.mul(MathUtil.div(isHaveClub, allclub, 2), 100).toString();
            portrait.setName("已填写机构");
            portrait.setValue(isHaveClub);
            portrait.setPer(per);
            portraitMap.add(portrait);
            // 机构不活跃
            portrait = new PortraitMap();
            per = MathUtil.mul(MathUtil.div(number, allclub, 2), 100).toString();
            portrait.setName("未填写机构");
            portrait.setValue(number);
            portrait.setPer(per);
            portraitMap.add(portrait);
            map.put("remark", portraitMap);
        }
        return ResponseJson.success(map);
    }

    /**
     * 协销登录(手机号，密码)
     *
     * @param mobile   手机号
     * @param password 密码
     * @param unionId  微信unionId
     * @return UserLoginVo
     */
    @Override
    public ResponseJson<UserLoginVo> passwordLogin(String mobile, String password, String unionId, Integer isUnion) {
        if (StringUtils.isBlank(mobile) || StringUtils.isBlank(password)) {
            return ResponseJson.error("请输入账号密码", null);
        }
        if (StringUtils.isBlank(unionId) && isUnion == null) {
            return ResponseJson.error("请输入微信unionId", null);
        }
        UserLoginVo seller = sellerMapper.getLoginSellerByMobile(mobile);

        if (null == seller || !Md5Util.md5(password).equals(seller.getPassword())) {
            return ResponseJson.error("账号密码不正确", null);
        }
        if (null == seller || 90 != seller.getServiceStatus()) {
            return ResponseJson.error("登录账号已下线，请联系客服", null);
        }
        // 生成token
        String token = JwtUtil.createToken(seller.getUserId());
        // 为了过期续签，将token存入redis，并设置超时时间
        redisService.set(token, token, JwtUtil.getExpireTime());
        seller.setToken(token);
        if (isUnion == null) {
            Map<Object, Object> infoData = redisService.getEntries("wxInfo:applets:" + unionId);
            String openId = (String) infoData.get(WeChatService.Keys.OPEN_ID);
            sellerMapper.updateServiceProviderByUserId(seller.getUserId(), openId, unionId);
            log.info("协销账号密码登录openid>>>>" + openId + " ,unionId>>>>>" + unionId);
        }
        seller.setManager(sellerMapper.findManager(mobile));
        return ResponseJson.success(seller);
    }

    /**
     * 采购员验证码登录 --组织
     *
     * @param loginCodeDto
     * @return
     */
    @Override
    public ResponseJson<UserLoginVo> organizeCodeLogin(LoginCodeDto loginCodeDto) {
        String mobile = loginCodeDto.getMobile();
        String unionId = loginCodeDto.getUnionId();
        String code = loginCodeDto.getCode();
        if (StringUtils.isBlank(mobile)) {
            return ResponseJson.error("请输入账号密码", null);
        }
        if (StringUtils.isBlank(unionId)) {
            return ResponseJson.error("请输入微信unionId", null);
        }
        if (StringUtils.isBlank(code)) {
            return ResponseJson.error("请输入验证码", null);
        }
        // 判断redis中是否存在
        boolean exists = redisService.exists("code:" + mobile);
        if (exists) {
            // 查看验证码是否过期
            long expireTime = redisService.getExpireTime("code:" + mobile);
            if (expireTime < 0) {
                return ResponseJson.error(-1, "验证码已失效，请重新获取", null);
            }
            // 获取redis手机短信验证码
            Object randomCode = redisService.get("code:" + mobile);

            if (!ObjectUtils.isEmpty(randomCode)) {
                if (code.equals(randomCode.toString())) {
                    redisService.remove("code:" + mobile);
                    // 根据手机号获取协销
                    UserLoginVo seller = sellerMapper.getLoginSellerByMobile(mobile);
                    if (null == seller || 90 != seller.getServiceStatus()) {
                        return ResponseJson.error("登录账号已下线，请联系客服", null);
                    }
                    // 生成token
                    String token = JwtUtil.createToken(seller.getUserId());
                    // 为了过期续签，将token存入redis，并设置超时时间
                    redisService.set(token, token, JwtUtil.getExpireTime());
                    seller.setToken(token);
                    Map<Object, Object> infoData = redisService.getEntries("wxInfo:applets:" + unionId);
                    String openId = (String) infoData.get(WeChatService.Keys.OPEN_ID);
                    sellerMapper.updateServiceProviderByUserId(seller.getUserId(), openId, unionId);
                    log.info("采购员登录openid>>>>" + openId + " ,unionId>>>>>" + unionId);
                    // seller.setManager(sellerMapper.findManager(mobile));

                    // 根据手机号获取用户信息
                    UserLoginVo baseUser = loginMapper.getLoginOrganizeUserByMobileOrEmail(mobile);
                    // 协销下线不在登录协销登录
                    if (null != baseUser.getUserIdentity() && 1 == baseUser.getUserIdentity()) {
                        if (null != baseUser.getServiceStatus() && 90 != baseUser.getServiceStatus()) {
                            seller = new UserLoginVo();
                            seller.setOpenId(openId);
                            seller.setUnionId(unionId);
                            return ResponseJson.error(-1, "采购员已下线", seller);
                        }
                    }
                    // 绑定微信信息
                    Integer operationUser = loginMapper.getOperationUser(mobile);
                    log.info("operationUser===" + operationUser);
                    /*if (null == operationUser) {
                        // 绑定微信
                        OperationVo operationVo = new OperationVo();
                        operationVo.setOrganizeId(baseUser.getOrganizeId());
                        operationVo.setUserType(1);
                        operationVo.setUserId(baseUser.getUserId());
                        operationVo.setClubId(baseUser.getClubId());
                        operationVo.setMobile(baseUser.getMobile());
                        operationVo.setLinkName(baseUser.getUserName());
                        operationVo.setStatus(2);
                        operationVo.setUnionId(unionId);
                        operationVo.setBindTime(new Date());
                        operationVo.setAddTime(new Date());
                        operationVo.setDelFlag(0);
                        loginMapper.insertOperation(operationVo);
                    }*/
                    return ResponseJson.success(seller);
                } else {
                    return ResponseJson.error(-1, "验证码错误，请确认验证码输入", null);
                }
            } else {
                return ResponseJson.error(-1, "验证码错误, 请重新获取", null);
            }
        }
        return ResponseJson.error();
    }

    /**
     * 待注册机构列表
     *
     * @param userId 协销用户id
     * @return ClubTemporaryVo
     */
    @Override
    public ResponseJson<PageInfo<ClubTemporaryVo>> temporaryClub(Integer userId, String searchName, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ClubTemporaryVo> clubTemporaryList = sellerMapper.findClubTemporary(userId, searchName);
        PageInfo<ClubTemporaryVo> pageInfo = new PageInfo<>(clubTemporaryList);
        return ResponseJson.success(pageInfo);
    }

    @Override
    public ResponseJson<String> modifyTemporaryClub(ClubTemporaryDto temporaryDto) {
        sellerMapper.updateClubTemporary(temporaryDto);
        return ResponseJson.success("");
    }

    @Override
    public ResponseJson<String> deleteTemporaryClub(Integer id) {
        sellerMapper.deleteTemporaryClub(id);
        return ResponseJson.success("");
    }

    /**
     * 所有的机构列表
     *
     * @param searchWord 搜索关键字
     * @param pageNum
     * @param pageSize
     */
    @Override
    public ResponseJson<PageInfo<ClubVo>> getAllClubList(String searchWord, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ClubVo> clubList = sellerMapper.getAllClubList(searchWord);
        PageInfo<ClubVo> pageData = new PageInfo<>(clubList);
        return ResponseJson.success(pageData);
    }

    /**
     * 协销个人中心
     *
     * @param userId 协销用户id
     */
    @Override
    public ResponseJson<ServiceProviderPo> getSellerHome(Integer userId) {
        // 协销用户
        ServiceProviderPo seller = sellerMapper.getSellerByUserId(userId);
        if (null == seller) {
            return ResponseJson.error("未查询到此协销人员！", null);
        }
        return ResponseJson.success(seller);
    }


    @Override
    public ResponseJson setSellerHome(ServiceProviderPo serviceProviderPo) {
        // 协销用户
        if (StringUtils.isNotBlank(serviceProviderPo.getImage())) {
            sellerMapper.setSellerUserHome(serviceProviderPo.getUserId(), serviceProviderPo.getImage());
        }
        if (StringUtils.isNotBlank(serviceProviderPo.getQrCode())) {
            sellerMapper.setSellerHome(serviceProviderPo);
        }
        return ResponseJson.success("");
    }

    @Override
    public ResponseJson<List<CmBehaviorRecordVo>> getBehaviorRecordClub(Integer type, Integer spId, String accessTime) {
        List<CmBehaviorRecordVo> behaviorRecordYesterdayClub = null == type  //null 机构访问通知， 1内容库访问通知
                ? sellerMapper.getBehaviorRecordYesterdayClub(spId, accessTime)
                : sellerMapper.getBehaviorRecordMinuteClub(spId, accessTime);
        for (CmBehaviorRecordVo cmBehaviorRecordVo : behaviorRecordYesterdayClub) {
            String pageLabel = null == type
                    ? sellerMapper.getBehaviorRecordYesterdayPageLabel(spId, cmBehaviorRecordVo.getClubId(), accessTime)
                    : sellerMapper.getBehaviorRecordMinutePageLabel(spId, cmBehaviorRecordVo.getClubId(), accessTime);
            cmBehaviorRecordVo.setPageLabel(pageLabel);
        }
        return ResponseJson.success(behaviorRecordYesterdayClub);
    }

    @Override
    public ResponseJson<List<CmBehaviorRecordVo>> getBehaviorRecordClubFrom(Integer type, Integer spId, Integer clubId, String accessTime) {

        List<CmBehaviorRecordVo> behaviorRecordYesterdayClubFrom = null == type  //null 机构访问通知， 1内容库访问通知
                ? sellerMapper.getBehaviorRecordYesterdayClubFrom(spId, clubId, accessTime)
                : sellerMapper.getBehaviorRecordMinuteClubFrom(spId, clubId, accessTime);
        for (CmBehaviorRecordVo cmBehaviorRecordVo : behaviorRecordYesterdayClubFrom) {
            String pageLabel = null == type
                    ? sellerMapper.getBehaviorRecordYesterdayPageLabel(spId, cmBehaviorRecordVo.getClubId(), accessTime)
                    : sellerMapper.getBehaviorRecordMinutePageLabel(spId, cmBehaviorRecordVo.getClubId(), accessTime);
            cmBehaviorRecordVo.setPageLabel(pageLabel);
            cmBehaviorRecordVo.setAccessDuration(calculationTime(cmBehaviorRecordVo.getAccessDuration()));
            if (cmBehaviorRecordVo.getProductID() != 0 && cmBehaviorRecordVo.getPageType().equals("6")) {
                ProductItemVo productShown = shopMapper.getProductShown(cmBehaviorRecordVo.getProductID());
                cmBehaviorRecordVo.setTitleId(cmBehaviorRecordVo.getProductID());
                cmBehaviorRecordVo.setTitle(productShown.getName());
                cmBehaviorRecordVo.setTitleImage(productShown.getImage());
            } else if (cmBehaviorRecordVo.getPageType().equals("11")) {
                //获取文章id
                Integer id = null;
                Pattern pattern = Pattern.compile("info/detail-(.*?)-");
                Matcher matcher = pattern.matcher(cmBehaviorRecordVo.getPagePath());
                if (matcher.find()) {
                    id = Integer.valueOf(matcher.group(1));
                }
                ShopArticleVo info = articleMapper.getShopArticleById(id);
                cmBehaviorRecordVo.setTitleId(id);
                cmBehaviorRecordVo.setTitle(info.getTitle());
                cmBehaviorRecordVo.setTitleImage(info.getGuidanceImage());
            }
        }
        return ResponseJson.success(behaviorRecordYesterdayClubFrom);
    }

    @Override
    public ResponseJson<List<ServiceProviderVo>> getServiceTeam(Integer spId, Integer status) {
        Integer leaderId = sellerMapper.findLeaderIdByServiceId(spId);
        Integer managerId = sellerMapper.findmanagerIdByServiceId(spId);
        List<ServiceProviderVo> serviceProviderVos = new ArrayList<>();
        if (null != leaderId) {
            serviceProviderVos = sellerMapper.findServices(spId, status);
        }
        if (null != managerId) {
            serviceProviderVos = sellerMapper.findAllServices(spId, status);
        }
        //个人返回空，组长返回小组所有人
        return ResponseJson.success(serviceProviderVos);
    }

    /**
     * 机构重点访问页面
     *
     * @param clubId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PageInfo<RetuenDataVo>> getClubRecord(Integer clubId, int pageNum, int pageSize) {

        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        // 获取机构访问日期
        List<RetuenDataVo> data = sellerMapper.getClubAccessDate(clubId);
        // 访问时间集合
        List<String> access = data.stream().map(RetuenDataVo::getAccessDate).collect(Collectors.toList());
        // 访问来源数据
        List<BehaviorRecodeVo> region = clubMapper.selRegion(null, null, 1, access);

        // 机构访问记录
        List<BehaviorRecodeVo> recordDataList = sellerMapper.getClubKeynoteRecord(clubId, access);
        String format = "";
        // 组装数据
        if (null != data && data.size() > 0) {
            for (RetuenDataVo rd : data) {
                // 该日期下机构访问记录
                List<BehaviorRecodeVo> recordList = recordDataList.stream().filter(r -> r.getAccessDate().equals(rd.getAccessDate())).collect(Collectors.toList());

                for (BehaviorRecodeVo record : recordList) {
                    // 图片处理
                    if (StringUtils.isNotBlank(record.getProductImage())) {
                        record.setProductImage(ImageUtils.getImageURL("product", record.getProductImage(), 0, wwwDomain));
                    }
                    String time = calculationTime(record.getAccessDuration());
                    record.setAccessDuration(time);
                    record.setAccessNewTime(dateFormat.format(record.getAccessTime()));
                    String s = simpleDateFormat.format(record.getAccessTime());

                    // 访问来源
                    if (region.size() != 0) {
                        for (BehaviorRecodeVo behaviorRecord : region) {
                            format = simpleDateFormat.format(behaviorRecord.getAccessTime());
                            if (StringUtils.isNotBlank(record.getPageType()) && StringUtils.isNotBlank(behaviorRecord.getPageType())) {
                                if (s.equals(format)) {
                                    record.setAccessSource(behaviorRecord.getAccessSource());
                                }
                            }
                        }
                    }
                }
                rd.setRecord(recordList);
            }
            // 没有重点访问页面数据删除不回显
            data.removeIf(d -> d.getRecord().size() <= 0);
        }
        PageHelper.startPage(pageNum, pageSize);
        PageInfo<RetuenDataVo> page = new PageInfo<>(data);
        return ResponseJson.success(page);
    }

    /**
     * 协销不活跃机构列表
     *
     * @param serviceProviderId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PageInfo<ClubVo>> getUnActiveClubList(Integer serviceProviderId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ClubVo> unActiveClub = sellerMapper.getUnActiveClub(serviceProviderId);
        for (ClubVo club : unActiveClub) {
            setClubNumber(club);
        }
        PageInfo<ClubVo> page = new PageInfo<>(unActiveClub);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PageInfo<ProviderTaskVo>> getTaskList(Integer serviceProviderId, Integer taskType, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ProviderTaskVo> tasks = sellerMapper.getTaskList(serviceProviderId, taskType);
        PageInfo<ProviderTaskVo> page = new PageInfo<>(tasks);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson receiveTask(Integer serviceProviderId, Integer taskId) {
        sellerMapper.receiveTask(serviceProviderId, taskId);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<ProviderTaskVo> getTaskDetail(HttpServletRequest request, Integer taskId, Integer serviceProviderId, Integer userId) {
        asyncService.serviceTask(request, serviceProviderId, taskId, userId);
        ProviderTaskVo taskDetail = sellerMapper.getTaskDetail(taskId);
        String image = ImageUtils.getImageURL("product", taskDetail.getMainImage(), 0, wwwDomain);
        taskDetail.setMainImage(image);
        return ResponseJson.success(taskDetail);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson taskAudit(TaskPushDto dto) {
        sellerMapper.insertTaskAudit(dto);
        /**
         * 二次提交清空历史图片
         */
        sellerMapper.deleteTaskImages(dto);
        sellerMapper.insertTaskImages(dto);
        sellerMapper.updateTaskAudit(dto);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PageInfo<ShopTaskVo>> getShopTaskList(Integer shopId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ShopTaskVo> tasks = sellerMapper.getShopTaskList(shopId);
        tasks.forEach(t -> {
            t.setMainImage(ImageUtils.getImageURL("product", t.getMainImage(), 0, wwwDomain));
        });
        PageInfo<ShopTaskVo> page = new PageInfo<>(tasks);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<ProviderTaskVo> getProviderTaskDetail(Integer taskId, Integer serviceProviderId) {
        ProviderTaskVo taskDetail = sellerMapper.getProviderTaskDetail(taskId, serviceProviderId);
        return ResponseJson.success(taskDetail);
    }

    /**
     * 机构编号
     *
     * @param club
     */
    public void setClubNumber(ClubVo club) {
        String newClubId = club.getClubId().toString();
        int maxLen = 6;
        int len = newClubId.length();
        if (len < maxLen) {
            for (int i = 0; i < (maxLen - len); i++) {
                newClubId = "0" + newClubId;
            }
        }
        club.setNewClubId(newClubId);
    }

    /**
     * 时间计算
     *
     * @param recordTime
     * @return
     */
    public String calculationTime(String recordTime) {
        double doc = Double.parseDouble(recordTime);
        int num = (int) doc;
        //小时
        int HH = 0;
        // 分钟
        int mm = 0;
        //秒
        int ss = 0;
        int item = num / 1000;
        if ((item / 60) > 0) {
            mm = item / 60;
            ss = item % 60;
        } else {
            ss = item;
        }
        if ((mm / 60) > 0) {
            HH = mm / 60;
            mm = mm % 60;
        }
        String str = HH + ":" + mm + ":" + ss;
        SimpleDateFormat dateFormat = new SimpleDateFormat("HH:mm:ss");
        Date parse = null;
        try {
            parse = dateFormat.parse(str);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        String format = dateFormat.format(parse);
        return format;
    }
}
